@@ -365,4 +365,39 @@ if(identical(reclass(as.xts(sample.its)),sample.its)) {
 } else cat("ERROR")
 cat("\n\n")
 
-rm(sample.ts,sample.its,sample.zoo,sample.timeSeries,sample.matrix,sample.data.frame)
+library(tseries)
+sample.irts <- irts(as.POSIXct(index(sample.zoo)),coredata(sample.zoo))
+cat("Testing as.xts.irts:\n")
+cat("  is.irts(sample.irts): ")
+if(is.irts(sample.irts)) {
+  cat("\t\tOK")
+} else cat("ERROR")
+cat("\n")
+cat("  as.xts(sample.irts): ")
+if(is.xts(as.xts(sample.irts))) {
+  cat("\t\t\tOK")
+} else cat("ERROR")
+cat("\n")
+cat("  reclass(as.xts(sample.irts)): ")
+if(identical(reclass(as.xts(sample.irts)),sample.irts)) {
+  cat("\tOK")
+} else cat("ERROR")
+cat("\n\n")
+
+rm(sample.ts,sample.its,sample.irts,sample.zoo,sample.timeSeries,sample.matrix,sample.data.frame)
+rm(convert.time.series)
+detach('package:zoo')
+detach('package:xts')
+detach('package:robustbase')
+detach('package:MASS')
+detach('package:RUnit')
+detach('package:spatial')
+detach('package:tcltk')
+detach('package:fUtilities')
+detach('package:fEcofin')
+detach('package:fCalendar')
+detach('package:fSeries')
+detach('package:Hmisc')
+detach('package:its')
+detach('package:quadprog')
+detach('package:tseries')
